Plan7 (`pyhmmer.plan7`)
=======================

.. currentmodule:: pyhmmer.plan7

.. automodule:: pyhmmer.plan7


Profile Hidden Markov Models
----------------------------

.. autosummary::

    HMM
    Profile
    OptimizedProfile
    OptimizedProfileBlock

.. toctree::
    :caption: Profile Hidden Markov Models
    :maxdepth: 1
    :hidden:

    Profile Hidden Markov Models <hmms>


Parsers
-------

.. autosummary::

    HMMFile
    HMMPressedFile

.. toctree::
    :caption: Parsers
    :maxdepth: 1
    :hidden:

    Parsers <parsers>


Pipelines
---------

.. autosummary::

    Pipeline
    LongTargetsPipeline
    Builder
    Background

.. toctree::
    :caption: Pipelines
    :maxdepth: 1
    :hidden:

    Pipelines <pli>


Results
-------

.. autosummary::

    TopHits
    Hit
    Domains
    Domain
    Alignment

.. toctree::
    :caption: Results
    :maxdepth: 1
    :hidden:

    Results <results>


Traces
------

.. autosummary::

    TraceAligner
    Traces
    Trace

.. toctree::
    :caption: Traces
    :maxdepth: 1
    :hidden:

    Traces <traces>


Iterative Searches
------------------

.. autosummary::

    IterativeSearch
    IterationResult

.. toctree::
    :caption: Iterative Searches
    :maxdepth: 1
    :hidden:

    Iterative Searches <iter>


Miscellaneous
-------------

.. autosummary::

    Cutoffs
    EvalueParameters
    Offsets
    Transitions

.. toctree::
    :caption: Miscellaneous
    :maxdepth: 1
    :hidden:

    Miscellaneous <misc>
